# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/inventory/customer/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/inventory/customer/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Inventory\\Customer\\": "packages/inventory/customer/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Inventory\Customer\Providers\CustomerServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Customer'  => Inventory\Customer\Facades\Customer::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Inventory\\CustomerTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Inventory\Customer\Providers\CustomerServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Inventory\Customer\Providers\CustomerServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Inventory\Customer\Providers\CustomerServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/customer/{modulename}

**User**

    http://path-to-route-folder/user/customer/{modulename}

**Public**

    http://path-to-route-folder/customers


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/customer/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/customer/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/customer/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/customer/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/customer/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/customer/{modulename}/{slug}
    METHOD: GET